using System;
using System.Collections.Generic;
using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Widgets;

namespace pomppu_possu;

/// @author suvitoivanen
/// @version 14.02.2025
/// <summary>
/// Eeppinen tasohyppely peli
/// </summary>
/// Kenttä pitää vielä luoda tekstitiedostoa käyttäen
/// Täytyy lisätä hyppy käskyihin
/// Lisäsin kuvat Content kansioon mutta ohjelma ei käänny nyt
/// Vaihtelin muutamia nimiä, kun herjasi niitä keltasena
public class PomppuPossu : PhysicsGame
{
    private const double NOPEUS = 200;
    private const double HYPPYNOPEUS = 750;
    private const int RUUDUN_KOKO = 40;

    private PlatformCharacter pomppuPossu;
   // private Image pomppuPossunKuva = LoadImage("pomppupossu.png");
   // private Image porkkanaKuva = LoadImage("porkkananKuva.png");

   // private SoundEffect _pisteAani = LoadSoundEffect("maali.wav");

    public override void Begin()
    {
        Gravity = new Vector(0, -1000);

        LuoKentta();
        
        Level.Size = new Vector(1920, 1080);
        SetWindowSize(1920, 1080);
        CenterWindow();
        Camera.ZoomToAllObjects(100);
        Level.CreateBorders();
        Level.Background.Color = Color.SpringGreen;

       // PlatformCharacter pomppuPossu = new PlatformCharacter(30, 80, Shape.Rectangle);
       // pomppuPossu.Image = _pomppuPossunKuva;
       //pomppuPossu.Mass = 4.0;
       // Add(pomppuPossu);
        
        

        Keyboard.Listen(Key.Up, ButtonState.Pressed, Hyppaa, "Pelaaja hyppää", pomppuPossu, HYPPYNOPEUS);
        Keyboard.Listen(Key.Left, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa vasemmalle", pomppuPossu, -NOPEUS);
        Keyboard.Listen(Key.Right, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa oikealle", pomppuPossu, NOPEUS);

        for (int i = 0; i < 10; i++)
        {
            Color[] varit = { Color.Black, Color.White };
            Megaporkkanat megaporkkana = new Megaporkkanat(60, 60, varit);
            megaporkkana.Shape = Shape.Circle;
            megaporkkana.Position = RandomGen.NextVector(Level.BoundingRect);
            megaporkkana.MakeStatic();
           // megaporkkana.Image = _porkkanaKuva;
            AddCollisionHandler<PhysicsObject, Megaporkkanat>(pomppuPossu, megaporkkana, TormattiinEsineeseen);
            Add(megaporkkana);
        }
        // tein version jossa tasot luodaan omalla aliohjelmalla 
        //for (int i = 0; i < 5; i++)
        //{
        //    Tasot paikallaan = new Tasot(150, 20);
        //    paikallaan.MakeStatic();
        //    paikallaan.Position = RandomGen.NextVector(Level.BoundingRect);
        //    Add(paikallaan);
        //}
        
        
        Keyboard.Listen(Key.Escape, ButtonState.Pressed, ConfirmExit, "Lopeta peli");
    }
    // loin kentän aliohjelmaa käyttäen, jotta saadaan 
    private void LuoKentta()
    {
        TileMap kentta = TileMap.FromLevelAsset("kentta1.txt");
        kentta.SetTileMethod('#', LisaaTaso);
        kentta.SetTileMethod('N', LisaaPelaaja);
        Level.Background.CreateGradient(Color.White, Color.SkyBlue);
    }

    private void LisaaTaso(Vector paikka, double leveys, double korkeus)
    {
        Tasot taso = new Tasot(leveys, korkeus);
        taso.Position = paikka;
        Add(taso);
    }
    private void LisaaPelaaja(Vector paikka, double leveys, double korkeus)
    {
        pomppuPossu = new PlatformCharacter(leveys, korkeus);
        pomppuPossu.Position = paikka;
        pomppuPossu.Mass = 4.0;
        //pomppuPossu.Image = pomppuPossunKuva;
        //AddCollisionHandler(pomppuPossu, "tahti", TormaaTahteen);
        Add(pomppuPossu);
    }
    private void Liikuta(PlatformCharacter pomppuPossu, double nopeus)
    {
        pomppuPossu.Walk(nopeus);
    }

    private void Hyppaa(PlatformCharacter pomppuPossu, double nopeus)
    {
        pomppuPossu.Jump(nopeus);
    }

    public void TormattiinEsineeseen(PhysicsObject tormaaja, Megaporkkanat kohde)
    {
        kohde.OtaVastaanOsuma();
       // _pisteAani.Play(); // Yritin lisätä megaporkkanoihin, en osannu xD
        MessageDisplay.Add("Megaporkkana kerätty!"); //Lisäsin viestin
    }

    /// <summary>
    /// Liikuttaa fysiikkaoliota.
    /// </summary>
    /// <param name="liikuteltava">Liikutettava</param>
    /// <param name="suunta">Suunta</param>
    public void Liikuta(PhysicsObject liikuteltava, Vector suunta)
    {
        liikuteltava.Push(suunta);
    }
        // Pomppu possun megamaailma

        
}


